#! /bin/sh

#
# scrubber_day.sh -- Execute scrubber daily
#
# Licensed Materials - Property of IBM
# Rational ClearCase
# (C) Copyright IBM Corp. 1991, 2014.  All Rights Reserved.
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp
#
# Revision history:
# lwa			12/03/91	initial version
#

# This script runs the scrubber once a day over all mounted VOBs
# whose storage directory is on this host.  This is the "default"
# scrubber script, suitable for most sites which do not run close
# to the size limit on their pools.  It is especially suitable for
# pools configured with the default pool parameters (which do not
# place an upper bound on the pool size).

# Sites with very limited pool space will want to run the scrubber
# more frequently; and other sites may need to customize this
# script in other ways.  See the Clearcase documentation for more
# information on customizing the scrubber execution.

ATRIA_DIR=${CLEARCASEHOME:-${ATRIAHOME:-/opt/rational/clearcase}}

# Just run the scrubber in "forced scrub" mode on all mounted 
# local VOBs

if [ -d /var/adm/rational/clearcase/log ] 
then
    LOGDIR=/var/adm/rational/clearcase/log
else
    echo "Can't find ClearCase log file directory"
    exit 1
fi	

LOG=${LOGDIR}/scrubber_log
$ATRIA_DIR/etc/scrubber -f -a
STATUS=$?
if [ $STATUS != 0 ]; then
	date
	HOSTNAME=`uname -n`
	if [ $STATUS = 2 ] ; then
	    echo "ClearCase scrubber on $HOSTNAME got non-fatal error (exit status $STATUS)"
	    echo "However, all VOBs were scrubbed"
	else
	    echo "ClearCase scrubber failed on $HOSTNAME with exit status $STATUS"
	    echo "Some VOBs were NOT scrubbed"
	fi
	echo "See ${HOSTNAME}:$LOG"
fi

exit $STATUS

